==> zenmake-0.10.0.tar.gz: zenmake-0.10.0/demos/external-deps/1-makefile/project/buildconf.py <==

features = {
    'db-format' : 'py',
    'provide-dep-targets' : True,
}

foolibdir = '../foo-lib'

def triggerConfigure(**kwargs):
    #print(kwargs)
    return False

dependencies = {
    'foo-lib-d' : {
        'rootdir': foolibdir,
        'export-includes' : foolibdir,
        'targets': {
            'shared-lib' : {
                'dir' : foolibdir + '/_build_/debug',
                'type': 'shlib',
                'name': 'fooutil',
            },
            'static-lib' : {
                'dir' : foolibdir + '/_build_/debug',
                'type': 'stlib',
                'name': 'fooutil',
            },
        },
        'rules' : {
            'configure': { # just for testing
                'cmd' : './configure',
                'shell' : True,
                'trigger' : {
                    'paths-dont-exist' : dict(
                        startdir = foolibdir,
                        include = '**/*.label',
                    ),
                    'func' : triggerConfigure,
                },
            },
            'build' : 'make debug',
            #'build' : {
            #    'cmd' : 'make debug',
            #    'shell' : False,
            #},
            #'clean' : 'make cleandebug',
            'clean' : {
                # clean 'foo-lib' with command 'clean', it's just demo
                'cmd' : 'make cleandebug',
                'shell' : False,
                'zm-commands' : 'clean',
            },
        },
    },
    'foo-lib-r' : {
        'rootdir': foolibdir,
        'export-includes' : foolibdir,
        'targets': {
            'shared-lib' : {
                'dir' : foolibdir + '/_build_/release',
                'type': 'shlib',
                'name': 'fooutil',
            },
            'static-lib' : {
                'dir' : foolibdir + '/_build_/release',
                'type': 'stlib',
                'name': 'fooutil',
            },
        },
        'rules' : {
            'configure': '',
            'build' : 'make release',
            'clean' : 'make cleanrelease',
        },
    },
}

tasks = {
    'util' : {
        'features' : 'cxxshlib',
        'source'   : 'shlib/**/*.cpp',
        'use.select' : {
            'debug'   : 'foo-lib-d:static-lib',
            'release' : 'foo-lib-r:static-lib',
        },
        'config-actions'  : [
            { 'do' : 'check-headers', 'names' : 'cstdio iostream' },
        ],
    },
    'program' : {
        'features' : 'cxxprogram',
        'source'   : 'prog/**/*.cpp',
        'use.select' : {
            'debug'   : 'util foo-lib-d:shared-lib',
            'release' : 'util foo-lib-r:shared-lib',
        },
    },
}

buildtypes = {
    'debug' : {
        'cxxflags' : '-O0 -g',
    },
    'release' : {
        'cxxflags' : '-O2',
    },
    'default' : 'debug',
}

==> zenmake-0.11.0.tar.gz: zenmake-0.11.0/demos/external-deps/1-makefile/project/buildconf.py <==

general = {
    'db-format' : 'py',
    'provide-edep-targets' : True,
}

foolibdir = '../foo-lib'

def triggerConfigure(**kwargs):
    #print(kwargs)
    return False

edeps = {
    'foo-lib-d' : {
        'rootdir': foolibdir,
        'export-includes' : foolibdir,
        'targets': {
            'shared-lib' : {
                'dir' : foolibdir + '/_build_/debug',
                'type': 'shlib',
                'name': 'fooutil',
            },
            'static-lib' : {
                'dir' : foolibdir + '/_build_/debug',
                'type': 'stlib',
                'name': 'fooutil',
            },
        },
        'rules' : {
            'configure': { # just for testing
                'cmd' : './configure',
                'shell' : True,
                'trigger' : {
                    'paths-dont-exist' : dict(
                        startdir = foolibdir,
                        incl = '**/*.label',
                    ),
                    'func' : triggerConfigure,
                },
            },
            'build' : 'make debug',
            #'build' : {
            #    'cmd' : 'make debug',
            #    'shell' : False,
            #},
            #'clean' : 'make cleandebug',
            'clean' : {
                # clean 'foo-lib' with command 'clean', it's just demo
                'cmd' : 'make cleandebug',
                'shell' : False,
                'zm-commands' : 'clean',
            },
        },
    },
    'foo-lib-r' : {
        'rootdir': foolibdir,
        'export-includes' : foolibdir,
        'targets': {
            'shared-lib' : {
                'dir' : foolibdir + '/_build_/release',
                'type': 'shlib',
                'name': 'fooutil',
            },
            'static-lib' : {
                'dir' : foolibdir + '/_build_/release',
                'type': 'stlib',
                'name': 'fooutil',
            },
        },
        'rules' : {
            'configure': '',
            'build' : 'make release',
            'clean' : 'make cleanrelease',
        },
    },
}

tasks = {
    'util' : {
        'features' : 'cxxshlib',
        'source'   : 'shlib/**/*.cpp',
        'use.select' : {
            'debug'   : 'foo-lib-d:static-lib',
            'release' : 'foo-lib-r:static-lib',
        },
        'configure'  : [
            { 'do' : 'check-headers', 'names' : 'cstdio iostream' },
        ],
    },
    'program' : {
        'features' : 'cxxprogram',
        'source'   : 'prog/**/*.cpp',
        'use.select' : {
            'debug'   : 'util foo-lib-d:shared-lib',
            'release' : 'util foo-lib-r:shared-lib',
        },
    },
}

buildtypes = {
    'debug' : {
        'cxxflags' : '-O0 -g',
    },
    'release' : {
        'cxxflags' : '-O2',
    },
    'default' : 'debug',
}
